@@ -7,15 +7,18 @@ from .helper import (
     checksum_end,
     checksum_field,
     checksum_start,
+    const,
     const_into,
     eval_into,
     hook_end,
     packing,
     probe,
+    string,
     tell,
     tell_into,
     unpacking,
     validate,
+    varlist,
     virtual,
 )
 from .special import action, align, alignto, hook, padding, seek, skip
@@ -35,6 +38,7 @@ __all__ = [
     "checksum_field",
     "checksum_start",
     "cond",
+    "const",
     "const_into",
     "eval_into",
     "field",
@@ -46,11 +50,13 @@ __all__ = [
     "repeat",
     "seek",
     "skip",
+    "string",
     "subfield",
     "switch",
     "tell",
     "tell_into",
     "unpacking",
     "validate",
+    "varlist",
     "virtual",
 ]
